@@ -75,6 +75,15 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         dbus.mainloop.glib.DBusGMainLoop(set_as_default = True)
         self.dbus = dbus.SystemBus()
         self.dbus.add_signal_receiver(self.dbus_signal_cb, "display_status_ind", "com.nokia.mce.signal", None, "/com/nokia/mce/signal")
+        self.dbus.add_signal_receiver(self.dbus_alarm_cb, "queue_status_ind", "com.nokia.alarmd", None, "/com/nokia/alarmd")
+
+    def dbus_alarm_cb(self, alarms, desktop, actdead, noboot):
+        if desktop != actdead :
+            self.clock.set_alarm_enabled(True)
+            self.clock.set_alarm_time(datetime.fromtimestamp(actdead))
+        else :
+            self.clock.set_alarm_enabled(False)
+        self.drawing_area.queue_draw()
 
     def dbus_signal_cb(self, msg):
         if msg == "off" :
@@ -115,6 +124,18 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
         dialog.vbox.pack_start(self.twelve_hour_mode_button, True, True, 0)
         self.twelve_hour_mode_button.show()
 
+        self.fill_button = hildon.CheckButton(gtk.HILDON_SIZE_FINGER_HEIGHT)
+        self.fill_button.set_active(self.clock.get_fill())
+        self.fill_button.set_label("Fill")
+        dialog.vbox.pack_start(self.fill_button, True, True, 0)
+        self.fill_button.show()
+
+        self.color_button = gtk.ColorButton()
+        self.color_button.set_color(self.clock.get_gdk_color())
+        self.color_button.set_label("Color")
+        dialog.vbox.pack_start(self.color_button, True, True, 0)
+        self.color_button.show()
+
         ok_button = hildon.Button(gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL, "Ok")
         ok_button.connect("clicked", self.settings_ok_cb, dialog)
         dialog.action_area.pack_start(ok_button, True, True, 0)
@@ -124,11 +145,20 @@ class AdvancedClockPlugin(hildondesktop.StatusMenuItem):
 
     def settings_ok_cb(self, widget, dialog):
         self.clock_style = self.style_button.get_active()
+
+        old_clock = self.clock
         self.clock = getattr(clocks[self.clock_style], clock_names[self.clock_style])(self.drawing_area)
+
         self.clock.set_show_seconds(self.show_seconds_button.get_active())
         self.clock.set_twelve_hour_mode(self.twelve_hour_mode_button.get_active())
+        self.clock.set_fill(self.fill_button.get_active())
+        self.clock.set_gdk_color(self.color_button.get_color())
 
         self.clock.resize()
+
+        self.clock.set_alarm_enabled(old_clock.get_alarm_enabled())
+        self.clock.set_alarm_time(old_clock.get_alarm_time())
+
         self.drawing_area.queue_draw()
     
         dialog.destroy()
